(** Glyph lists *)

(** A ZapfDingbats glyph list *)
val dingbatmap : (string * int list) list

(** The Adobe Glyph List *)
val glyphmap : (string * int list) list

(** A Truetype Glyph List *)
val truetypemap : (string * int list) list

